@@ -1,13 +1,13 @@
 import os
 
-from mite.scenario import StopScenario
+from mite.scenario import StopVolumeModel
 from mite_http import mite_http
 
 
 def volume_model_factory(n):
     def vm(start, end):
         if start > 60 * 15:  # Will run for 15 mins
-            raise StopScenario
+            raise StopVolumeModel
         return n
 
     vm.__name__ = f"volume model {n}"
